<?php
/**
 * @package   AkeebaLoginGuard
 * @copyright Copyright (c)2016-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\Component\LoginGuard\Administrator\Controller;

// Prevent direct access
defined('_JEXEC') or die;

use Akeeba\Component\LoginGuard\Administrator\Controller\Mixin\ControllerEvents;
use Akeeba\Component\LoginGuard\Administrator\Controller\Mixin\GetRedirectionAware;
use Akeeba\Component\LoginGuard\Administrator\Controller\Mixin\RegisterControllerTasks;
use Akeeba\Component\LoginGuard\Administrator\Controller\Mixin\ReturnURLAware;
use Akeeba\Component\LoginGuard\Administrator\Controller\Mixin\ReusableModels;
use Akeeba\Component\LoginGuard\Administrator\Event\Callback;
use Akeeba\Component\LoginGuard\Administrator\Helper\Tfa as TfaHelper;
use Joomla\CMS\Application\CMSApplication;
use Joomla\CMS\Language\Text;
use Joomla\CMS\MVC\Controller\BaseController;
use Joomla\CMS\MVC\Factory\MVCFactoryInterface;
use Joomla\CMS\Plugin\PluginHelper;
use Joomla\Input\Input;
use RuntimeException;

class CallbackController extends BaseController
{
	use ControllerEvents;
	use GetRedirectionAware;
	use RegisterControllerTasks;
	use ReturnURLAware;
	use ReusableModels;

	public function __construct($config = [], MVCFactoryInterface $factory = null, ?CMSApplication $app = null, ?Input $input = null)
	{
		parent::__construct($config, $factory, $app, $input);

		$this->registerDefaultTask('callback');
	}


	/**
	 * Implement a callback feature, typically used for OAuth2 authentication
	 *
	 * @param   bool         $cachable    Can this view be cached
	 * @param   array|bool   $urlparams   An array of safe url parameters and their variable types, for valid values see
	 *                                    {@link JFilterInput::clean()}.
	 *
	 * @return  void
	 */
	public function callback($cachable = false, $urlparams = false): void
	{
		$app = $this->app;

		// Get the Method and make sure it's non-empty
		$method = $this->input->getCmd('method', '');

		if (empty($method))
		{
			throw new RuntimeException(Text::_('JERROR_ALERTNOAUTHOR'), 403);
		}

		PluginHelper::importPlugin('loginguard');

		TfaHelper::triggerEvent(new Callback($method));

		/**
		 * The first plugin to handle the request should either redirect or close the application. If we are still here
		 * no plugin handled the request successfully. Show an error.
		 */
		throw new RuntimeException(Text::_('JERROR_ALERTNOAUTHOR'), 403);
	}
}