<?php
/**
 * @package   AkeebaLoginGuard
 * @copyright Copyright (c)2016-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\Component\LoginGuard\Administrator\Event\Backport;

// Prevent direct access
defined('_JEXEC') or die;

use Akeeba\Passwordless\Assert\InvalidArgumentException;

/**
 * Defines an Event which has an append-only array argument named 'result'.
 *
 * This is used for Events whose handlers are expected to return something when called, similar to
 * how many plugin events worked in earlier versions of Joomla.
 *
 * This interface is partially implemented by the ResultAware trait. The typeCheckResult method is
 * implemented by the various ResultType*Aware traits. Your event needs to use both the ResultAware
 * trait and one of the ResultType*Aware traits. For example, if your event returns boolean results
 * you need to use the ResultAware and ResultTypeBooleanAware traits in your event.
 *
 * IMPORTANT: THIS IS A BACKPORT FROM MY CONTRIBUTED CODE TO JOOMLA FOR IMPROVING EVENTS HANDLING IN JOOMLA 4.X. THIS
 * CODE WILL BE REMOVED WHEN WE DROP SUPPORT FOR JOOMLA VERSIONS WHICH DO NOT INCLUDE THIS CODE.
 *
 * @since 6.0.0
 */
interface ResultAwareInterface
{
	/**
	 * Appends data to the result array of the event.
	 *
	 * @param   mixed  $data  What to add to the result array.
	 *
	 * @return  void
	 * @since   6.0.0
	 */
	public function addResult($data): void;

	/**
	 * Checks the type of the data being appended to the result argument.
	 *
	 * @param   mixed  $data  The data to type check
	 *
	 * @return  void
	 * @throws  InvalidArgumentException
	 *
	 * @internal
	 * @since   6.0.0
	 */
	public function typeCheckResult($data): void;
}