<?php
/**
 * @package   AkeebaLoginGuard
 * @copyright Copyright (c)2016-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

// Prevent direct access
defined('_JEXEC') || die;

use Akeeba\Component\LoginGuard\Administrator\View\Captive\HtmlView;
use Joomla\CMS\Factory;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Router\Route;

/** @var HtmlView $this */

$session = Factory::getApplication()->getSession();

if (!is_null($this->browserId) || !$session->get('com_loginguard.browserIdCodeLoaded', false))
{
	throw new RuntimeException("Someone's been naughty.");
}

/**
 * Browser Fingerprinting Code
 *
 * ## Why not use Joomla's Remember Me cookie feature?
 *
 * These cookies are linked to a user account, not a browser. We want to link bypassing the Two Step Verification to a
 * specific browser and device.
 *
 * It's still a bad idea, it's just not as bad as being able to steal a cookie to bypass this feature.
 *
 * ## Loading dependencies locally
 *
 * We now load the FingerprintJS2 v.2.1.0 and the MurmurHash3 library  from a local file with a stupid name because
 * Firefox blocks anything with "fingerprint" in the name. Moreover when CloudFlare's CDN went down it was impossible to
 * access any site using this fingerprinting code.
 *
 * The com_loginguard.security asset has a dependency on com_loginguard.magic. The former contains our own code, the
 * latter contains the following files:
 *   https://cdnjs.cloudflare.com/ajax/libs/fingerprintjs2/2.1.0/fingerprint2.min.js
 *   https://cdnjs.cloudflare.com/ajax/libs/murmurhash3js/3.0.1/murmurHash3js.js
 */
$this->document->getWebAssetManager()
	->useScript('com_loginguard.security');

?>
<div class="loginguard-captive-fingerprint-container">
	<h2>
		<?= Text::_('COM_LOGINGUARD_HEAD_FINGERPRINTING'); ?>
	</h2>
	<div>
		<p id="loginguard-captive-fingeprint-info" style="display: none">
			<?= Text::_('COM_LOGINGUARD_LBL_FINGERPRINTING_MESSAGE'); ?>
		</p>
		<form action="<?= Route::_('index.php?option=com_loginguard&view=Captive') ?>"
			  id="akeebaLoginguardForm"
			  method="post">
			<?= HTMLHelper::_('form.token') ?>
			<input type="hidden" id="akeebaLoginguardFormBrowserId" name="browserId" value="">

			<noscript>
				<h3>
					<?= Text::_('COM_LOGINGUARD_LBL_FINGERPRINTING_NOSCRIPT_HEAD') ?>
				</h3>
				<p>
					<?= Text::_('COM_LOGINGUARD_LBL_FINGERPRINTING_NOSCRIPT_BODY') ?>
				</p>

				<input type="submit" class="loginguard-button-primary-large">
			</noscript>
		</form>
	</div>
</div>
